[![Binder](https://mybinder.org/badge.svg)](https://mybinder.org/v2/gh/AgrinessEdgeIoT/portiapy/master?urlpath=lab/tree/docs/pt-br/portiapy-examples.ipynb) [![PyPI version](https://badge.fury.io/py/portiapy.svg)](https://badge.fury.io/py/portiapy)

# PortiaPy

This is a package for handling Agriness Edge's REST API. 

## Getting Started

### Prerequisites

* [requests ^2.19.1](http://docs.python-requests.org/en/master/)
* [pytz ^2018.5](http://pytz.sourceforge.net/)
* [python-dateutil ^2.7.3](https://dateutil.readthedocs.io/en/stable/)
* [plotly ^3.1.1](https://plot.ly/)
* [pandas ^0.23.4](https://pandas.pydata.org/)
* [arrow ^0.12.1](https://arrow.readthedocs.io/en/latest/)

### Installing

``` pip3 install portiapy ```

## Examples

There are examples available in [pt-br](./docs/examples/pt-br/portiapy-examples.ipynb) and en-us. 

You can start playing with the *portiapy* package on a Jupyter Lab container by clicking at: [![Binder](https://mybinder.org/badge.svg)](https://mybinder.org/v2/gh/AgrinessEdgeIoT/portiapy/master?urlpath=lab/tree/docs/pt-br/portiapy-examples.ipynb) 
